import { IgrDataGrid, IgrDataGridToolbar, IgrGridSelectedItemsChangedEventArgs } from 'igniteui-react-grids';
import GrandChildComponent from './GrandChildComponent';
import { useState, useRef } from 'react';
import { checkContainsValue } from '../helper/helperFunctions';

export interface IProps {
  grid1Data: any;
  onGrid1Ref: any;
  grid1Ref: any;
}

const ChildComponent = (props: IProps) => {
  const [grid2Data, setGrid2Data] = useState<any[]>();
  const grid2Ref = useRef<IgrDataGrid>();
  const data = [
    { Id: '1', Salary: '300.0', },
    { Id: '2', Salary: '600.0', },
    { Id: '3', Salary: '3880.0', },
    { Id: '4', Salary: '11300.0', },
  ];
  let toolbarList1: IgrDataGridToolbar;
  let toolbarList2: IgrDataGridToolbar;

  const onGrid1Ref = (grid: IgrDataGrid) => {
    if (!grid) {
      return;
    }

    props.onGrid1Ref(grid);
  };

  const onGrid2Ref = (grid: IgrDataGrid) => {
    if (!grid) {
      return;
    }

    grid2Ref.current = grid;
  };

  // Setting up column chooser items for Order Grid
  const onToolbarList1Ref = (toolbar: IgrDataGridToolbar) => {
    toolbarList1 = toolbar;
    if (toolbarList1 !== null && props.grid1Ref) {
      toolbarList1.targetGrid = props.grid1Ref;
    }
  };

  // Setting up column chooser items for Order Grid
  const onToolbarList2Ref = (toolbar: IgrDataGridToolbar) => {
    toolbarList2 = toolbar;
    if (toolbarList2 !== null && grid2Ref.current) {
      toolbarList2.targetGrid = grid2Ref.current;
    }
  };

  const grid1ActiveCellChanged = (grid: IgrDataGrid, event: IgrGridSelectedItemsChangedEventArgs) => {
    if (event?.currentItems?.item.length > 0) {
      const activeRow = event.currentItems.item(0);
      setGrid2Data(activeRow?.OrderCollection);
    }
  };

  let count = 106;
  const onAddButtonClick = () => {
    const newRecord = {
      Id: count++,
      Name: 'XYZ',
      Street: 'Street6',
      City: 'City6',
      Birthday: '2021-09-01T08:44:06',
      Salary: '2000',
      OrderCollection: [],
    };
    props.grid1Data.push(newRecord);
    props.grid1Ref.notifyInsertItem(0, newRecord);
  };

  const onUpdateButtonClick = () => {
    const newRecord = {
      Id: '105',
      Name: 'XYZ-Updated',
      Street: 'Street-Updated',
      City: 'City-Updated',
      Birthday: '2021-09-01T08:44:06',
      Salary: '2000',
      OrderCollection: [],
    };

    const result = checkContainsValue(props.grid1Data, newRecord.Id, 'Id');
    if (result) {
      props.grid1Data[result.index] = newRecord;
      props.grid1Ref.notifySetItem(result.index, result.row, newRecord);
    }
  };
  //console.log('Render Child Component **');
  return (
    <>
      <div className="options">
        <button className="options-button" onClick={onAddButtonClick}>
          Add Row
        </button>
        <button className="options-button" onClick={onUpdateButtonClick}>
          Update Row
        </button>
      </div>

      <IgrDataGridToolbar ref={onToolbarList1Ref} toolbarTitle="Grid1" columnChooser="true" columnChooserText="Add Column" />
      <GrandChildComponent grid1Data={data} onGrid1Ref={onGrid1Ref} grid1ActiveCellChanged={grid1ActiveCellChanged} />
    </>
  );
};

export default ChildComponent;
